#include "editor.h"

//{{{
void map_properties(void)
{
	enter_properties_state();
}
//}}}
//{{{
void map_resize(void)
{
	enter_resize_state();
}
//}}}
//{{{
void map_next(void)
{
	if(current_map_num+1 < num_maps) {
		set_current_map(current_map_num+1);
		draw_current_map();
	}
}
//}}}
//{{{
void map_previous(void)
{
	if(current_map_num > 0) {
		set_current_map(current_map_num-1);
		draw_current_map();
	}
}
//}}}
//{{{
void map_import_level(void)
{
	char filename[64];
	FILE *fin;
	file_header header;
	int ii=current_map_num;
	int format; // 0: DCKye, 1+: SKye revision N
	int offset;
	dialog_read_string("Import what file?", filename, 30, 25, 100, 40);
	
	fin = fopen(filename, "rb");
	if(!fin) {
		draw_current_map();
		show_dialog("File not found.", 25, 25, 70, 30);
		return;
	}
	
	if(fread(&header, sizeof(file_header), 1, fin) < 1) {
		fclose(fin);
		show_dialog("Corrupt file.", 25, 25,  70, 30);
		return;
	}
	if( strncmp(header.magic_bytes, "SKye", 4) ) {
		fseek(fin, 0, SEEK_SET);
		format = 0;
	} else {
		format = header.revision;
	}
	
	if(format == 0)
	{
		do {
			map_insert();
			ii++;
		} while( load_dckye_level(fin, current_map_num));
		map_delete();
		set_current_map(ii-1);
	} else if(format == 1) {
		do {
			map_insert();
			ii++;
		} while( load_skye_level_r1(fin, current_map_num));
		map_delete();
		set_current_map(ii-1);
	} else if(format == 2) {
		for(ii=0; ii<header.num_levels; ii++) {
			fseek(fin, sizeof(header)+ii*sizeof(short), SEEK_SET);
			fread(&offset, sizeof(short), 1, fin);
			fseek(fin, offset, SEEK_SET);
			map_insert();
			load_skye_level_r2(fin, current_map_num);
		}
	}
	
	fclose(fin);
}
//}}}
//{{{
void map_insert(void)
{
	int ii;
	editor_map added_map;
	set_num_maps(num_maps+1);
	added_map = maps[num_maps-1];
	for(ii=num_maps-1; ii>current_map_num; ii--)
		maps[ii] = maps[ii-1];
	maps[current_map_num+1] = added_map;
	set_current_map(current_map_num+1);
	default_map();
}
//}}}
//{{{
void map_delete(void)
{
	int ii;
	if(num_maps==1) {
		draw_current_map();
		show_dialog("You cannot delete the last map!", 25, 25, 75, 30);
		return;
	}
	cleanup_map(&maps[current_map_num]);
	for(ii=current_map_num; ii<num_maps-1; ii++)
		maps[ii] = maps[ii+1];
	maps[num_maps-1].t = NULL; // HACKHACK - stupid way to protect against
	                           // free'ing
	set_num_maps(num_maps-1);
	draw_current_map();
}
//}}}
//{{{
void map_move_up(void)
{
	editor_map temp;
	
	if(current_map_num == 0) return; // Can't move up if already at the top
	
	temp = maps[current_map_num];
	maps[current_map_num] = maps[current_map_num-1];
	maps[current_map_num-1] = temp;
	set_current_map(current_map_num-1);
}
//}}}
//{{{
void map_move_down(void)
{
	editor_map temp;
	
	if(current_map_num+1 >= num_maps) return;
	
	temp = maps[current_map_num];
	maps[current_map_num] = maps[current_map_num+1];
	maps[current_map_num+1] = temp;
	set_current_map(current_map_num+1);
}
//}}}

